@@ -8,17 +8,20 @@ from __future__ import annotations
 import collections
 import collections.abc
 import datetime
+import decimal
 import functools
 import itertools
 import operator
 import uuid
 from typing import Any, Mapping, MutableMapping, Sequence, TypeVar
 
+import ibis
 import ibis.expr.datatypes as dt
 import ibis.expr.operations as ops
 import ibis.expr.schema as sch
 import ibis.expr.types as ir
 from ibis import util
+from packaging import version
 
 from ..proto.substrait import algebra_pb2 as stalg
 from ..proto.substrait import type_pb2 as stt
@@ -98,7 +101,11 @@ def _time(dtype: dt.Time) -> stt.Type:
 @translate.register
 def _decimal(dtype: dt.Decimal) -> stt.Type:
     return stt.Type(
-        decimal=stt.Type.Decimal(scale=dtype.scale, precision=dtype.precision)
+        decimal=stt.Type.Decimal(
+            scale=dtype.scale,
+            precision=dtype.precision,
+            nullability=_nullability(dtype),
+        )
     )
 
 
@@ -182,7 +189,10 @@ def _schema(schema: sch.Schema) -> stt.NamedStruct:
 
     return stt.NamedStruct(
         names=names,
-        struct=stt.Type.Struct(types=list(map(translate, schema.types))),
+        struct=stt.Type.Struct(
+            types=list(map(translate, schema.types)),
+            nullability=stt.Type.Nullability.NULLABILITY_REQUIRED,
+        ),
     )
 
 
@@ -264,6 +274,11 @@ def _literal_float64(_: dt.Float64, value: float) -> stalg.Expression.Literal:
     return stalg.Expression.Literal(fp64=value)
 
 
+@translate_literal.register
+def _literal_decimal(_: dt.Decimal, value: decimal.Decimal) -> stalg.Expression.Literal:
+    raise NotImplementedError
+
+
 @translate_literal.register
 def _literal_string(_: dt.String, value: str) -> stalg.Expression.Literal:
     return stalg.Expression.Literal(string=value)
@@ -441,6 +456,19 @@ def _translate_window_bounds(
     return translate_preceding(*preceding), translate_following(*following)
 
 
+if version.parse(ibis.__version__) >= version.parse("3.0.0"):
+
+    @translate.register(ops.Alias)
+    def alias_op(
+        op: ops.Alias,
+        expr: ir.ValueExpr,
+        compiler: SubstraitCompiler,
+        **kwargs: Any,
+    ) -> stalg.Expression:
+        # For an alias, dispatch on the underlying argument
+        return translate(op.arg.op(), op.arg, compiler, **kwargs)
+
+
 @translate.register(ops.ValueOp)
 def value_op(
     op: ops.ValueOp,
